import pandas as pd

# CO2 data can be found at
# https://github.com/owid/co2-data

# An explanation of columns is at
# https://github.com/owid/co2-data/blob/master/owid-co2-codebook.csv


def plot_global_co2_per_year(csv_filename):

    # convert the CSV file into a Pandas dataframe
    data = pd.read_csv(csv_filename)

    # get the subset of the data where the country column is equal to 'World'
    world = data[data["country"].eq("World")]

    # create a new column where co2 is measured in gigatons instead of megatons
    world["co2"].div(1000)

    # create a line plot with x = year and y = GTco2
    # set the figure size, title, xlabel, ylabel
    plot = world.plot.line(
        x="year",
        y="co2",
        figsize=(10, 4),
        title="Atmospheric $CO_2$ Emissions, World ",
        xlabel="year",
        ylabel="Gt $CO_2$ per year",
    )

    # get a figure for the plot
    fig = plot.get_figure()

    # save the figure to a file
    fig.savefig("global-co2-per-year.png")


if __name__ == "__main__":
    plot_global_co2_per_year("owid-co2-data.csv")
